package MyAtom::Controller::MyService;

use strict;
use warnings;
use base 'Catalyst::Controller::Atompub::Service';

=head1 NAME

MyAtom::Controller::MyService - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=cut


=head1 AUTHOR

Takeru INOUE,,,

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
